'Selma': Ava DuVernay and Oprah Winfrey turn '60s civil unrest into a stirring, relevant film | Boston Herald
Keywords: Tribune Content Agency, Selma, Ava DuVernay, Oprah Winfrey, Movie News, Movies, Entertainment
Date: 2014-12-29T05:38:00-05:00

Skip to main content

# 'Selma': Ava DuVernay and Oprah Winfrey turn '60s civil unrest into a stirring, relevant film

## 544d821ca7e14a199c3247b449ab2a7e.jpg

### Photo by:

The Associated Press
This image released by Paramount Pictures shows, standing from left, Tessa Thompson, Omar Dorsey, Colman Domingo, David Oyelowo as Martin Luther King, Jr., André Holland, Corey Reynolds and Lorraine Toussaint in a scene from "Selma." (AP Photo/Paramount Pictures, Atsushi Nishijima)
1
Monday, December 29, 2014
Print Email Comments

### By:

April P. Bernard

Annie Lee Cooper, a 54-year-old motel maid, simply wanted to vote. But in 1965, as one of 100-plus black locals in line to register in Selma, Alabama, she confronted a segregationist sheriff - and ended up on the ground, beaten viciously with a billy club. When asked to portray the unlikely freedom fighter in the big-screen drama Selma, Oprah Winfrey hesitated: "I didn't want to do it because in every movie I'm hitting somebody!" she tells Us. (Previous wallops: The Color Purple and The Butler.) But director Ava DuVernay, 42, persuaded her (more on that below), and Winfrey, 60, joined the Christmas Day release - about Martin Luther King Jr. (David Oyelowo) and his Selma-toMontgomery marches for civil rights - as a star and producer. Shortly after DuVernay became the first black female director nominated for a Golden Globe (and the film's Oscar buzz began building), the two sat down with Us to talk, laugh and, in Winfrey's case, get a little misty-eyed.

Ava, how did Oprah do when she had to punch the sheriff?

AD She was all in. She had no problem working with the stunt guys to be taken down. I kept saying to them, "Please, can you just be a little more careful?" And they're like, "She's falling on her own!"

OW I did it every time.

With Ferguson and Eric Garner in the headlines, is Selma particularly meaningful now?

OW It's a jaw-dropping thing that this piece of art can meet this cultural moment that's so rich, so robust, so bursting with the energy of people finding their voices. This film's about being heard. I feel like this film, not to overstate it, but it is here for a reason in this moment.

Will you be screening this for your close friend Barack Obama?

OW For sure. Our desire is to go to the White House and show it to him.

With such intense scenes - marchers were teargassed - was it tough keeping your emotions in check?

OW The very first time I saw it with the other producers, they're all taking notes. And I'm, like, sobbing. And I thought, OK, I guess as a producer you're not supposed to sob (continuing in a choked voice) so let me just take some notes too. I'm gonna blow my nose and stop crying.

Oprah, how did Ava try to woo you for Selma?

OW I was just gonna be in the background going, "Yay!" But she sent me the link to a story about Annie Lee Cooper when she turned 100, and it said every day she watched the Oprah show eating a tuna-fish sandwich! And Ava says, "Don't you think it would make her proud to know that you played her?" And I go, "Yeeesss, yes, it would."

It probably also helped that as a girl you wanted to be Dr. King!

OW What made me think I was gonna do that? I was 12, 13. I remember being at our yellow Formica kitchen table filling out one of those "What are you gonna be when you grow up?" forms, and my father was saying, "You can't be Dr. King because Dr. King is a man!" "Well, I'm gonna have me a church," I said.

What about you, Ava? Who was your idol?

AD (Pointing at Winfrey.) My mom had magazines with you on the cover on our coffee table since as long as I can remember, to the point where I thought you were my family member. She would tape your show at work and watch it at night. My mom would just say, "Look at her. Don't be like me, be like her," and get emotional.

OW Oh, God, I'm emotional about that (tearing up). You never told me that! (She playfully smacks DuVernay.) Don't tell me that in an interview for the first time!

Let's talk about something lighter. Ava, you worked on Scandal!

AD Imagine a geek fan getting a chance to direct her favorite show! I can make Tony Goldwyn be Fitz, and I can do whatever I want: "Walk over there. Now walk back. Turn. Oh, that looks good." You know what I mean? (Laughs.) So that was fun-fun.

So you're Team Fitz, then - not Team Jake?

AD Oh, Fitz.

OW Fitz.

AD Sorry, Scott Foley!

The Real-Life Heroes

Oyelowo says he gained insight from King friend Andrew Young, who revealed "the prankster … the man who was at times unsure." As for Ejogo, Winfrey says Martin Luther King III and sister Bernice found she "depicted their mother beautifully."

### More On:

Tribune Content Agency
Selma
Ava DuVernay
Oprah Winfrey

### Author(s):

### April P. Bernard

Print This Page Email This Page

## Join The Conversation

### View Comments (Be the first to comment) | Add a Comment

## Top Entertainment Stories